@@ -1,7 +1,10 @@
 #ifndef SIMPLE_STRING_H
 #define SIMPLE_STRING_H
-
+/*
+ * 単純な文字列操作クラス
+ */
 #include <string.h>
+#include <stdarg.h>
 
 typedef struct _String {
     char* raw_chars;
@@ -16,6 +19,7 @@ size_t string_len(String*);
 char* string_rawstr(String*);
 void string_free(String*);
 void string_replace(String*, char, char*);
+void string_appendf(String*, char*, ...);
 
 #endif
 /* vim: set ts=4 sw=4 sts=4 expandtab fenc=utf-8: */
